@@ -1,3 +1,138 @@
+
+#' Convert igraph graphs to graphNEL objects from the graph package
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.to.graphNEL()` was renamed to `as_graphnel()` to create a more
+#' consistent API.
+#' @inheritParams as_graphnel
+#' @keywords internal
+#' @export
+igraph.to.graphNEL <- function(graph) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.to.graphNEL()", "as_graphnel()")
+  as_graphnel(graph = graph)
+} # nocov end
+
+#' Convert graphNEL objects from the graph package to igraph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.from.graphNEL()` was renamed to `graph_from_graphnel()` to create a more
+#' consistent API.
+#' @inheritParams graph_from_graphnel
+#' @keywords internal
+#' @export
+igraph.from.graphNEL <- function(graphNEL, name = TRUE, weight = TRUE, unlist.attrs = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.from.graphNEL()", "graph_from_graphnel()")
+  graph_from_graphnel(graphNEL = graphNEL, name = name, weight = weight, unlist.attrs = unlist.attrs)
+} # nocov end
+
+#' Create graphs from adjacency lists
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.adjlist()` was renamed to `graph_from_adj_list()` to create a more
+#' consistent API.
+#' @inheritParams graph_from_adj_list
+#' @keywords internal
+#' @export
+graph.adjlist <- function(adjlist, mode = c("out", "in", "all", "total"), duplicate = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.adjlist()", "graph_from_adj_list()")
+  graph_from_adj_list(adjlist = adjlist, mode = mode, duplicate = duplicate)
+} # nocov end
+
+#' Bipartite adjacency matrix of a bipartite graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.incidence()` was renamed to `as_biadjacency_matrix()` to create a more
+#' consistent API.
+#' @inheritParams as_biadjacency_matrix
+#' @keywords internal
+#' @export
+get.incidence <- function(graph, types = NULL, attr = NULL, names = TRUE, sparse = FALSE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.incidence()", "as_biadjacency_matrix()")
+  as_biadjacency_matrix(graph = graph, types = types, attr = attr, names = names, sparse = sparse)
+} # nocov end
+
+#' Convert a graph to an edge list
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.edgelist()` was renamed to `as_edgelist()` to create a more
+#' consistent API.
+#' @inheritParams as_edgelist
+#' @keywords internal
+#' @export
+get.edgelist <- function(graph, names = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.edgelist()", "as_edgelist()")
+  as_edgelist(graph = graph, names = names)
+} # nocov end
+
+#' Creating igraph graphs from data frames or vice-versa
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.data.frame()` was renamed to `as_data_frame()` to create a more
+#' consistent API.
+#' @inheritParams as_data_frame
+#' @keywords internal
+#' @export
+get.data.frame <- function(x, what = c("edges", "vertices", "both")) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.data.frame()", "as_data_frame()")
+  as_data_frame(x = x, what = what)
+} # nocov end
+
+#' Convert a graph to an adjacency matrix
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.adjacency()` was renamed to `as_adjacency_matrix()` to create a more
+#' consistent API.
+#' @inheritParams as_adjacency_matrix
+#' @keywords internal
+#' @export
+get.adjacency <- function(graph, type = c("both", "upper", "lower"), attr = NULL, edges = FALSE, names = TRUE, sparse = igraph_opt("sparsematrices")) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.adjacency()", "as_adjacency_matrix()")
+  as_adjacency_matrix(graph = graph, type = type, attr = attr, edges = edges, names = names, sparse = sparse)
+} # nocov end
+
+#' Adjacency lists
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.adjlist()` was renamed to `as_adj_list()` to create a more
+#' consistent API.
+#' @inheritParams as_adj_list
+#' @keywords internal
+#' @export
+get.adjlist <- function(graph, mode = c("all", "out", "in", "total"), loops = c("twice", "once", "ignore"), multiple = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.adjlist()", "as_adj_list()")
+  as_adj_list(graph = graph, mode = mode, loops = loops, multiple = multiple)
+} # nocov end
+
+#' Adjacency lists
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `get.adjedgelist()` was renamed to `as_adj_edge_list()` to create a more
+#' consistent API.
+#' @inheritParams as_adj_edge_list
+#' @keywords internal
+#' @export
+get.adjedgelist <- function(graph, mode = c("all", "out", "in", "total"), loops = c("twice", "once", "ignore")) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "get.adjedgelist()", "as_adj_edge_list()")
+  as_adj_edge_list(graph = graph, mode = mode, loops = loops)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -20,7 +155,7 @@
 ###################################################################
 
 get.adjacency.dense <- function(graph, type = c("both", "upper", "lower"),
-                                attr = NULL, edges = FALSE, names = TRUE) {
+                                attr = NULL, weights = NULL, loops = c("once", "twice", "ignore"), names = TRUE) {
   ensure_igraph(graph)
 
   type <- igraph.match.arg(type)
@@ -30,11 +165,27 @@ get.adjacency.dense <- function(graph, type = c("both", "upper", "lower"),
     "both" = 2
   )
 
-  if (edges || is.null(attr)) {
+  if (is.logical(loops)) {
+    loops <- ifelse(loops, "once", "ignore")
+    lifecycle::deprecate_soft(
+      "2.1.0", "get.adjacency.dense(loops = 'must be a character')",
+      details = sprintf("Converting to get.adjacency.dense (loops = '%s')", loops)
+    )
+  }
+  loops <- igraph.match.arg(loops)
+  loops <- switch(loops,
+    "ignore" = 0L,
+    "twice" = 1L,
+    "once" = 2L
+  )
+
+  if (!is.null(weights)) weights <- as.numeric(weights)
+
+  if (is.null(attr)) {
     on.exit(.Call(R_igraph_finalizer))
     res <- .Call(
-      R_igraph_get_adjacency, graph, as.numeric(type),
-      as.logical(edges)
+      R_igraph_get_adjacency, graph, as.numeric(type), weights,
+      loops
     )
   } else {
     attr <- as.character(attr)
@@ -44,13 +195,11 @@ get.adjacency.dense <- function(graph, type = c("both", "upper", "lower"),
     exattr <- edge_attr(graph, attr)
     if (is.logical(exattr)) {
       res <- matrix(FALSE, nrow = vcount(graph), ncol = vcount(graph))
-    } else if (is.character(exattr)) {
-      res <- matrix("", nrow = vcount(graph), ncol = vcount(graph))
     } else if (is.numeric(exattr)) {
       res <- matrix(0, nrow = vcount(graph), ncol = vcount(graph))
     } else {
       stop(
-        "Sparse matrices must be either numeric or logical,",
+        "Matrices must be either numeric or logical, ",
         "and the edge attribute is not"
       )
     }
@@ -93,7 +242,7 @@ get.adjacency.dense <- function(graph, type = c("both", "upper", "lower"),
 }
 
 get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
-                                 attr = NULL, edges = FALSE, names = TRUE) {
+                                 attr = NULL, names = TRUE) {
   ensure_igraph(graph)
 
   type <- igraph.match.arg(type)
@@ -103,10 +252,7 @@ get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
   el <- as_edgelist(graph, names = FALSE)
   use.last.ij <- FALSE
 
-  if (edges) {
-    value <- seq_len(nrow(el))
-    use.last.ij <- TRUE
-  } else if (!is.null(attr)) {
+  if (!is.null(attr)) {
     attr <- as.character(attr)
     if (!attr %in% edge_attr_names(graph)) {
       stop("no such edge attribute")
@@ -114,7 +260,7 @@ get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
     value <- edge_attr(graph, name = attr)
     if (!is.numeric(value) && !is.logical(value)) {
       stop(
-        "Sparse matrices must be either numeric or logical,",
+        "Matrices must be either numeric or logical, ",
         "and the edge attribute is not"
       )
     }
@@ -164,7 +310,6 @@ get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
 #' defined in the \sQuote{`Matrix`} package, if `sparse` if
 #' `TRUE`.
 #'
-#' @aliases get.adjacency
 #' @param graph The graph to convert.
 #' @param type Gives how to create the adjacency matrix for undirected graphs.
 #'   It is ignored for directed graphs. Possible values: `upper`: the upper
@@ -183,7 +328,7 @@ get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
 #'   numeric. If the `sparse` argument is `FALSE`, then character is
 #'   also allowed. The reason for the difference is that the `Matrix`
 #'   package does not support character sparse matrices yet.
-#' @param edges Logical scalar, whether to return the edge ids in the matrix.
+#' @param edges `r lifecycle::badge("deprecated")` Logical scalar, whether to return the edge ids in the matrix.
 #'   For non-existant edges zero is returned.
 #' @param names Logical constant, whether to assign row and column names
 #'   to the matrix. These are only assigned if the `name` vertex attribute
@@ -206,25 +351,45 @@ get.adjacency.sparse <- function(graph, type = c("both", "upper", "lower"),
 #' @family conversion
 #' @export
 as_adjacency_matrix <- function(graph, type = c("both", "upper", "lower"),
-                                attr = NULL, edges = FALSE, names = TRUE,
+                                attr = NULL, edges = deprecated(), names = TRUE,
                                 sparse = igraph_opt("sparsematrices")) {
   ensure_igraph(graph)
 
-  if (!missing(edges)) {
-    warning("The `edges` argument of `as_adjacency_matrix` is deprecated; it will be removed in igraph 1.4.0")
+  if (lifecycle::is_present(edges) && isTRUE(edges)) {
+    lifecycle::deprecate_stop("2.0.0", "as_adjacency_matrix(edges = )")
   }
 
-  if (!sparse) {
-    get.adjacency.dense(graph, type = type, attr = attr, edges = edges, names = names)
+  if (sparse) {
+    get.adjacency.sparse(graph, type = type, attr = attr, names = names)
   } else {
-    get.adjacency.sparse(graph, type = type, attr = attr, edges = edges, names = names)
+    get.adjacency.dense(graph, type = type, attr = attr, weights = NULL, names = names, loops = "once")
   }
 }
 
+#' Convert a graph to an adjacency matrix
+#'
+#' `r lifecycle::badge("deprecated")`
+#' We plan to remove `as_adj()` in favor of the more explicitly named
+#' `as_adjacency_matrix()` so please use `as_adjacency_matrix()` instead.
+#'
 #' @export
-#' @rdname as_adjacency_matrix
-as_adj <- as_adjacency_matrix
+#' @inheritParams as_adjacency_matrix
+#' @keywords internal
+as_adj <- function(graph, type = c("both", "upper", "lower"),
+                   attr = NULL, edges = deprecated(), names = TRUE,
+                   sparse = igraph_opt("sparsematrices")) {
 
+  lifecycle::deprecate_soft("2.1.0", "as_adj()", "as_adjacency_matrix()")
+
+  as_adjacency_matrix(
+    graph = graph,
+    type = type,
+    attr = attr,
+    edges = edges,
+    names = names,
+    sparse = sparse
+  )
+}
 #' Convert a graph to an edge list
 #'
 #' Sometimes it is useful to work with a standard representation of a
@@ -232,7 +397,6 @@ as_adj <- as_adjacency_matrix
 #'
 #' `as_edgelist()` returns the list of edges in a graph.
 #'
-#' @aliases get.edgelist
 #' @param graph The graph to convert.
 #' @param names Whether to return a character matrix containing vertex
 #'   names (i.e. the `name` vertex attribute) if they exist or numeric
@@ -268,11 +432,11 @@ as_edgelist <- function(graph, names = TRUE) {
 
 #' Convert between directed and undirected graphs
 #'
-#' `as.directed()` converts an undirected graph to directed,
-#' `as.undirected()` does the opposite, it converts a directed graph to
+#' `as_directed()` converts an undirected graph to directed,
+#' `as_undirected()` does the opposite, it converts a directed graph to
 #' undirected.
 #'
-#' Conversion algorithms for `as.directed()`: \describe{
+#' Conversion algorithms for `as_directed()`: \describe{
 #' \item{"arbitrary"}{The number of edges in the graph stays the same, an
 #' arbitrarily directed edge is created for each undirected edge, but the
 #' direction of the edge is deterministic (i.e. it always points the same
@@ -291,7 +455,7 @@ as_edgelist <- function(graph, names = TRUE) {
 #' graph contained loop edges.}
 #' }
 #'
-#' Conversion algorithms for `as.undirected()`: \describe{
+#' Conversion algorithms for `as_undirected()`: \describe{
 #' \item{"each"}{The number of edges remains constant, an undirected edge
 #' is created for each directed one, this version might create graphs with
 #' multiple edges.} \item{"collapse"}{One undirected edge will be created
@@ -301,11 +465,11 @@ as_edgelist <- function(graph, names = TRUE) {
 #' edges are ignored. This mode might create multiple edges if there are more
 #' than one mutual edge pairs between the same pair of vertices.  } }
 #'
-#' @aliases as.directed as.undirected
+#' @aliases as_directed as_undirected
 #' @param graph The graph to convert.
 #' @param mode Character constant, defines the conversion algorithm. For
-#'   `as.directed()` it can be `mutual` or `arbitrary`. For
-#'   `as.undirected()` it can be `each`, `collapse` or
+#'   `as_directed()` it can be `mutual` or `arbitrary`. For
+#'   `as_undirected()` it can be `each`, `collapse` or
 #'   `mutual`. See details below.
 #' @return A new graph object.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
@@ -317,21 +481,23 @@ as_edgelist <- function(graph, names = TRUE) {
 #' @examples
 #'
 #' g <- make_ring(10)
-#' as.directed(g, "mutual")
+#' as_directed(g, "mutual")
 #' g2 <- make_star(10)
-#' as.undirected(g)
+#' as_undirected(g)
 #'
 #' # Combining edge attributes
 #' g3 <- make_ring(10, directed = TRUE, mutual = TRUE)
 #' E(g3)$weight <- seq_len(ecount(g3))
-#' ug3 <- as.undirected(g3)
+#' ug3 <- as_undirected(g3)
 #' print(ug3, e = TRUE)
-#' \dontrun{
+
+#' @examplesIf rlang::is_interactive()
 #' x11(width = 10, height = 5)
 #' layout(rbind(1:2))
 #' plot(g3, layout = layout_in_circle, edge.label = E(g3)$weight)
 #' plot(ug3, layout = layout_in_circle, edge.label = E(ug3)$weight)
-#' }
+
+#' @examples
 #'
 #' g4 <- make_graph(c(
 #'   1, 2, 3, 2, 3, 4, 3, 4, 5, 4, 5, 4,
@@ -339,28 +505,29 @@ as_edgelist <- function(graph, names = TRUE) {
 #'   9, 8, 9, 8, 9, 9, 10, 10, 10, 10
 #' ))
 #' E(g4)$weight <- seq_len(ecount(g4))
-#' ug4 <- as.undirected(g4,
+#' ug4 <- as_undirected(g4,
 #'   mode = "mutual",
 #'   edge.attr.comb = list(weight = length)
 #' )
 #' print(ug4, e = TRUE)
 #'
-as.directed <- to_directed_impl
+#' @cdocs igraph_to_directed
+as_directed <- to_directed_impl
 
-#' @rdname as.directed
+#' @rdname as_directed
 #' @param edge.attr.comb Specifies what to do with edge attributes, if
 #'   `mode="collapse"` or `mode="mutual"`.  In these cases many edges
 #'   might be mapped to a single one in the new graph, and their attributes are
 #'   combined. Please see [attribute.combination()] for details on
 #'   this.
 #' @export
-as.undirected <- function(graph, mode = c("collapse", "each", "mutual"), edge.attr.comb = igraph_opt("edge.attr.comb")) {
+as_undirected <- function(graph, mode = c("collapse", "each", "mutual"), edge.attr.comb = igraph_opt("edge.attr.comb")) {
   # Argument checks
   ensure_igraph(graph)
   mode <- switch(igraph.match.arg(mode),
-    "collapse" = 1,
-    "each" = 0,
-    "mutual" = 2
+    "collapse" = 1L,
+    "each" = 0L,
+    "mutual" = 2L
   )
   edge.attr.comb <- igraph.i.attribute.combination(edge.attr.comb)
 
@@ -385,7 +552,6 @@ as.undirected <- function(graph, mode = c("collapse", "each", "mutual"), edge.at
 #' ids of adjacent edges (according to the `mode` argument) of all
 #' vertices.
 #'
-#' @aliases get.adjedgelist
 #' @param graph The input graph.
 #' @param mode Character scalar, it gives what kind of adjacent edges/vertices
 #'   to include in the lists. \sQuote{`out`} is for outgoing edges/vertices,
@@ -403,7 +569,7 @@ as.undirected <- function(graph, mode = c("collapse", "each", "mutual"), edge.at
 #' vectors of the adjacency lists are coerced to `igraph.vs`, this can be
 #' a very expensive operation on large graphs.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [as_edgelist()], [as_adj()]
+#' @seealso [as_edgelist()], [as_adjacency_matrix()]
 #' @family conversion
 #' @export
 #' @keywords graphs
@@ -449,7 +615,6 @@ as_adj_list <- function(graph,
 }
 
 #' @rdname as_adj_list
-#' @aliases get.adjlist
 #' @export
 as_adj_edge_list <- function(graph,
                              mode = c("all", "out", "in", "total"),
@@ -495,7 +660,6 @@ as_adj_edge_list <- function(graph,
 #' attributes of the multiple edges are lost: they are all replaced by the
 #' attributes of the first of the multiple edges.
 #'
-#' @aliases igraph.from.graphNEL
 #' @param graphNEL The graphNEL graph.
 #' @param name Logical scalar, whether to add graphNEL vertex names as an
 #'   igraph vertex attribute called \sQuote{`name`}.
@@ -508,11 +672,10 @@ as_adj_edge_list <- function(graph,
 #'   whenever possible, before adding them to the igraph graph.
 #' @return `graph_from_graphnel()` returns an igraph graph object.
 #' @seealso [as_graphnel()] for the other direction,
-#' [as_adj()], [graph_from_adjacency_matrix()],
-#' [as_adj_list()] and [graph.adjlist()] for other
+#' [as_adjacency_matrix()], [graph_from_adjacency_matrix()],
+#' [as_adj_list()] and [graph_from_adj_list()] for other
 #' graph representations.
-#' @examples
-#' \dontrun{
+#' @examplesIf rlang::is_installed("graph")
 #' ## Undirected
 #' g <- make_ring(10)
 #' V(g)$name <- letters[1:10]
@@ -526,7 +689,6 @@ as_adj_edge_list <- function(graph,
 #' GNEL2 <- as_graphnel(g3)
 #' g4 <- graph_from_graphnel(GNEL2)
 #' g4
-#' }
 #' @family conversion
 #' @export
 graph_from_graphnel <- function(graphNEL, name = TRUE, weight = TRUE,
@@ -596,16 +758,15 @@ graph_from_graphnel <- function(graphNEL, name = TRUE, weight = TRUE,
 #' vertex names in the graphNEL graph. Otherwise numeric igraph vertex ids
 #' will be used for this purpose.
 #'
-#' @aliases igraph.to.graphNEL
 #' @param graph An igraph graph object.
 #' @return `as_graphnel()` returns a graphNEL graph object.
 #' @seealso [graph_from_graphnel()] for the other direction,
-#' [as_adj()], [graph_from_adjacency_matrix()],
-#' [as_adj_list()] and [graph.adjlist()] for
+#' [as_adjacency_matrix()], [graph_from_adjacency_matrix()],
+#' [as_adj_list()] and [graph_from_adj_list()] for
 #' other graph representations.
-#' @examples
+#'
+#' @examplesIf rlang::is_installed("graph")
 #' ## Undirected
-#' \dontrun{
 #' g <- make_ring(10)
 #' V(g)$name <- letters[1:10]
 #' GNEL <- as_graphnel(g)
@@ -618,7 +779,6 @@ graph_from_graphnel <- function(graphNEL, name = TRUE, weight = TRUE,
 #' GNEL2 <- as_graphnel(g3)
 #' g4 <- graph_from_graphnel(GNEL2)
 #' g4
-#' }
 #' @family conversion
 #' @export
 as_graphnel <- function(graph) {
@@ -659,7 +819,7 @@ as_graphnel <- function(graph) {
 
   g.n <- graph_attr_names(graph)
   if ("directed" %in% g.n) {
-    warning("Cannot add graph attribute `directed'")
+    cli::cli_warn("Cannot add graph attribute {.str directed}.")
     g.n <- g.n[g.n != "directed"]
   }
   for (n in g.n) {
@@ -705,14 +865,14 @@ get.incidence.dense <- function(graph, types, names, attr) {
   if (is.null(attr)) {
     on.exit(.Call(R_igraph_finalizer))
     ## Function call
-    res <- .Call(R_igraph_get_incidence, graph, types)
+    res <- .Call(R_igraph_get_biadjacency, graph, types)
 
     if (names && "name" %in% vertex_attr_names(graph)) {
-      rownames(res$res) <- V(graph)$name[res$row_ids + 1]
-      colnames(res$res) <- V(graph)$name[res$col_ids + 1]
+      rownames(res$res) <- V(graph)$name[res$row_ids]
+      colnames(res$res) <- V(graph)$name[res$col_ids]
     } else {
-      rownames(res$res) <- res$row_ids + 1
-      colnames(res$res) <- res$col_ids + 1
+      rownames(res$res) <- res$row_ids
+      colnames(res$res) <- res$col_ids
     }
     res$res
   } else {
@@ -811,7 +971,6 @@ get.incidence.sparse <- function(graph, types, names, attr) {
 #' boolean and `FALSE` for the vertices of the first kind and `TRUE`
 #' for vertices of the second kind.
 #'
-#' @aliases get.incidence
 #' @param graph The input graph. The direction of the edges is ignored in
 #'   directed graphs.
 #' @param types An optional vertex type vector to use instead of the
@@ -932,7 +1091,6 @@ as_data_frame <- function(x, what = c("edges", "vertices", "both")) {
 #' [as_adj_list()], do your modifications to the graphs and finally
 #' create again an igraph graph by calling `graph_from_adj_list()`.
 #'
-#' @aliases graph.adjlist
 #' @param adjlist The adjacency list. It should be consistent, i.e. the maximum
 #'   throughout all vectors in the list must be less than the number of vectors
 #'   (=the number of vertices in the graph).
@@ -957,19 +1115,20 @@ as_data_frame <- function(x, what = c("edges", "vertices", "both")) {
 #' g <- make_ring(10, directed = TRUE)
 #' al <- as_adj_list(g, mode = "out")
 #' g2 <- graph_from_adj_list(al)
-#' graph.isomorphic(g, g2)
+#' isomorphic(g, g2)
 #'
 #' ## Undirected
 #' g <- make_ring(10)
 #' al <- as_adj_list(g)
 #' g2 <- graph_from_adj_list(al, mode = "all")
-#' graph.isomorphic(g, g2)
+#' isomorphic(g, g2)
 #' ecount(g2)
 #' g3 <- graph_from_adj_list(al, mode = "all", duplicate = FALSE)
 #' ecount(g3)
 #' which_multiple(g3)
 #' @family conversion
 #' @export
+#' @cdocs igraph_adjlist
 graph_from_adj_list <- adjlist_impl
 
 
@@ -1068,3 +1227,35 @@ as.matrix.igraph <- function(x, matrix.type = c("adjacency", "edgelist"), ...) {
     edgelist = as_edgelist(graph = x, ...)
   )
 }
+
+#' Convert between directed and undirected graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `as.directed()` was renamed to `as_directed()` to create a more
+#' consistent API.
+#' @inheritParams as_directed
+#' @keywords internal
+#' @export
+as.directed <- function(graph, mode = c("mutual", "arbitrary", "random", "acyclic")) {
+  lifecycle::deprecate_soft("2.1.0", "as.directed()", "as_directed()")
+  as_directed(graph, mode = mode)
+}
+
+#' Convert between undirected and unundirected graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `as.undirected()` was renamed to `as_undirected()` to create a more
+#' consistent API.
+#' @inheritParams as_undirected
+#' @keywords internal
+#' @export
+as.undirected <- function(graph,
+                          mode = c("collapse", "each", "mutual"),
+                          edge.attr.comb = igraph_opt("edge.attr.comb")) {
+  lifecycle::deprecate_soft("2.1.0", "as.undirected()", "as_undirected()")
+  as_undirected(graph = graph, mode = mode, edge.attr.comb = edge.attr.comb)
+}
