@@ -90,6 +90,7 @@
 #' embed <- embed_adjacency_matrix(RDP, 5)
 #' @family embedding
 #' @export
+#' @cdocs igraph_adjacency_spectral_embedding
 embed_adjacency_matrix <- adjacency_spectral_embedding_impl
 
 
@@ -151,6 +152,7 @@ embed_adjacency_matrix <- adjacency_spectral_embedding_impl
 #'
 #' @family embedding
 #' @export
+#' @cdocs igraph_dim_select
 dim_select <- dim_select_impl
 
 
@@ -230,6 +232,7 @@ dim_select <- dim_select_impl
 #' RDP <- sample_dot_product(lpvs)
 #' embed <- embed_laplacian_matrix(RDP, 5)
 #' @family embedding
+#' @cdocs igraph_laplacian_spectral_embedding
 embed_laplacian_matrix <- laplacian_spectral_embedding_impl
 
 
@@ -263,8 +266,8 @@ embed_laplacian_matrix <- laplacian_spectral_embedding_impl
 #' vec.norm
 sample_sphere_surface <- function(dim, n = 1, radius = 1, positive = TRUE) {
   # Argument checks
-  dim <- as.integer(dim)
-  n <- as.integer(n)
+  dim <- as.numeric(dim)
+  n <- as.numeric(n)
   radius <- as.numeric(radius)
   positive <- as.logical(positive)
 
@@ -305,8 +308,8 @@ sample_sphere_surface <- function(dim, n = 1, radius = 1, positive = TRUE) {
 #' vec.norm
 sample_sphere_volume <- function(dim, n = 1, radius = 1, positive = TRUE) {
   # Argument checks
-  dim <- as.integer(dim)
-  n <- as.integer(n)
+  dim <- as.numeric(dim)
+  n <- as.numeric(n)
   radius <- as.numeric(radius)
   positive <- as.logical(positive)
 
@@ -342,7 +345,7 @@ sample_sphere_volume <- function(dim, n = 1, radius = 1, positive = TRUE) {
 #' colSums(lpvs.dir)
 sample_dirichlet <- function(n, alpha) {
   # Argument checks
-  n <- as.integer(n)
+  n <- as.numeric(n)
   alpha <- as.numeric(alpha)
 
   on.exit(.Call(R_igraph_finalizer))
