@@ -1,17 +1,11 @@
-
-has_glpk <- function() {
-  glpk <- TRUE
-  tryCatch(
-    cluster_optimal(make_ring(10)),
-    error = function(e) glpk <<- FALSE
-  )
-  glpk
-}
-
 skip_if_no_glpk <- function() {
   if (!has_glpk()) skip("No GLPK library")
 }
 
+skip_if_no_graphml <- function() {
+  if (!has_graphml()) skip("No GraphML support")
+}
+
 with_rng_version <- function(version, expr) {
   orig <- RNGkind()
   on.exit(do.call(RNGkind, as.list(orig)), add = TRUE)
@@ -26,8 +20,6 @@ local_rng_version <- function(version, .local_envir = parent.frame()) {
   orig
 }
 
-expect_that <- function(object, condition, info = NULL, label = NULL) {
-  suppressWarnings(
-    condition(object)
-  )
+expect_isomorphic <- function(g1, g2) {
+  expect_true(isomorphic(g1, g2))
 }
