@@ -1,13 +1,8 @@
 test_that("components works", {
-  set.seed(42)
-
-  gc <- function(graph) {
-    cl <- components(graph)
-    induced_subgraph(graph, which(cl$membership == which.max(cl$csize)))
-  }
+  withr::local_seed(42)
 
   rg <- function(n) {
-    gc(sample_gnp(n, 1 / n))
+    largest_component(sample_gnp(n, 1 / n))
   }
 
   G <- lapply(1:30, function(x) rg(sample(100, 1)))
@@ -16,9 +11,9 @@ test_that("components works", {
   allg <- disjoint_union(G)
   clu <- components(allg)
 
-  expect_that(as.numeric(table(clu$membership)), equals(clu$csize))
-  expect_that(sort(clu$csize), equals(sort(Gsize)))
-  expect_that(clu$no, equals(length(G)))
+  expect_equal(as.numeric(table(clu$membership)), clu$csize)
+  expect_equal(sort(clu$csize), sort(Gsize))
+  expect_equal(clu$no, length(G))
 })
 
 test_that("components names results", {
@@ -26,34 +21,24 @@ test_that("components names results", {
   V(g)$name <- letters[1:15]
 
   clu <- components(g)
-  expect_that(names(clu$membership), equals(letters[1:15]))
+  expect_equal(names(clu$membership), letters[1:15])
 })
 
 test_that("groups works", {
   g <- make_ring(10) + make_full_graph(5)
   gr <- groups(components(g))
 
-  expect_that(gr, equals(structure(list(`1` = 1:10, `2` = 11:15),
-    .Dim = 2L,
-    .Dimnames = list(c("1", "2"))
-  )))
+  expect_equal(gr, structure(list(`1` = 1:10, `2` = 11:15), .Dim = 2L, .Dimnames = list(c("1", "2"))))
 
   V(g)$name <- letters[1:15]
   gr <- groups(components(g))
 
-  expect_that(gr, equals(structure(
-    list(
-      `1` = letters[1:10],
-      `2` = letters[11:15]
-    ),
-    .Dim = 2L,
-    .Dimnames = list(c("1", "2"))
-  )))
+  expect_equal(gr, structure(list(`1` = letters[1:10], `2` = letters[11:15]), .Dim = 2L, .Dimnames = list(c("1", "2"))))
 })
 
 test_that("is_connected works", {
   g <- make_ring(10)
-  expect_that(g, is_connected)
+  expect_true(is_connected(g))
 
   g <- make_ring(10) + make_full_graph(5)
   expect_false(is_connected(g))
