@@ -4,14 +4,14 @@ test_that("graph_from_edgelist works", {
   g <- sample_gnp(50, 5 / 50)
   el <- as_edgelist(g)
   g2 <- graph_from_edgelist(el, directed = FALSE)
-  expect_true(graph.isomorphic(g, g2))
+  expect_isomorphic(g, g2)
 
   ####
 
   g <- sample_gnp(50, 5 / 50, directed = TRUE)
   el <- as_edgelist(g)
   g2 <- graph_from_edgelist(el, directed = TRUE)
-  expect_true(graph.isomorphic(g, g2))
+  expect_isomorphic(g, g2)
 
   ####
 
@@ -22,5 +22,5 @@ test_that("graph_from_edgelist works", {
   mode(el) <- "character"
   el[] <- n[el]
   g2 <- graph_from_edgelist(el, directed = TRUE)
-  expect_true(graph.isomorphic(g, g2))
+  expect_isomorphic(g, g2)
 })
