@@ -1,5 +1,5 @@
 test_that("make_lattice works", {
-  g <- make_lattice(dim = 2, length = 3, circular = F)
+  g <- make_lattice(dim = 2, length = 3, periodic = F)
   g2 <- make_empty_graph(n = 9) + edges(c(
     1, 2,
     1, 4,
@@ -16,7 +16,7 @@ test_that("make_lattice works", {
   ))
   expect_equal(as_edgelist(g), as_edgelist(g2))
 
-  g <- make_lattice(dim = 2, length = 3, circular = T)
+  g <- make_lattice(dim = 2, length = 3, periodic = T)
   g2 <- make_empty_graph(n = 9) + edges(c(
     1, 2,
     1, 4,
@@ -41,7 +41,7 @@ test_that("make_lattice works", {
 })
 
 test_that("make_lattice prints a warning for fractional length)", {
-  expect_warning(make_lattice(dim = 2, length = sqrt(2000)), "length was rounded")
+  expect_warning(make_lattice(dim = 2, length = sqrt(2000)), "`length` was rounded")
 
   suppressWarnings(g <- make_lattice(dim = 2, length = sqrt(2000)))
   g2 <- make_lattice(dim = 2, length = 45)
