@@ -54,7 +54,7 @@ test_that("a graph with a single vertex and no edges is tree", {
 })
 
 test_that("is_forest takes edge directions into account correctly", {
-  g <- make_graph(c(1,2, 2,3, 2,4, 5,4), n = 6, directed = TRUE)
+  g <- make_graph(c(1, 2, 2, 3, 2, 4, 5, 4), n = 6, directed = TRUE)
 
   expect_true(is_forest(g, mode = "all"))
   expect_false(is_forest(g, mode = "out"))
@@ -78,13 +78,13 @@ test_that("to_prufer and make_from_prufer works for trees", {
   g <- make_tree(13, 3, mode = "out")
   seq <- to_prufer(g)
   g2 <- make_from_prufer(seq)
-  g3 <- as.undirected(g)
+  g3 <- as_undirected(g)
   expect_true(isomorphic(g2, g3))
 
   g <- make_tree(13, 3, mode = "in")
   seq <- to_prufer(g)
   g2 <- make_from_prufer(seq)
-  g3 <- as.undirected(g)
+  g3 <- as_undirected(g)
   expect_true(isomorphic(g2, g3))
 })
 
@@ -102,40 +102,40 @@ test_that("to_prufer prints an error for non-trees", {
 test_that("sample_tree works", {
   g <- sample_tree(100)
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(99))
-  expect_that(vcount(g), equals(100))
+  expect_equal(ecount(g), 99)
+  expect_equal(vcount(g), 100)
   expect_true(is_tree(g))
 
   g <- sample_tree(50, directed = T)
   expect_true(is_directed(g))
-  expect_that(ecount(g), equals(49))
-  expect_that(vcount(g), equals(50))
+  expect_equal(ecount(g), 49)
+  expect_equal(vcount(g), 50)
   expect_true(is_tree(g))
 
   g <- sample_tree(200, method = "prufer")
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(199))
-  expect_that(vcount(g), equals(200))
+  expect_equal(ecount(g), 199)
+  expect_equal(vcount(g), 200)
   expect_true(is_tree(g))
 
   g <- sample_tree(200, method = "lerw")
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(199))
-  expect_that(vcount(g), equals(200))
+  expect_equal(ecount(g), 199)
+  expect_equal(vcount(g), 200)
   expect_true(is_tree(g))
 })
 
 test_that("sample_(tree(...)) works", {
   g <- sample_(tree(200, method = "prufer"))
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(199))
-  expect_that(vcount(g), equals(200))
+  expect_equal(ecount(g), 199)
+  expect_equal(vcount(g), 200)
   expect_true(is_tree(g))
 
   g2 <- sample_(tree(200, method = "prufer"))
   expect_false(is_directed(g2))
-  expect_that(ecount(g2), equals(199))
-  expect_that(vcount(g2), equals(200))
+  expect_equal(ecount(g2), 199)
+  expect_equal(vcount(g2), 200)
   expect_true(is_tree(g2))
   expect_false(identical_graphs(g, g2))
 })
@@ -143,16 +143,16 @@ test_that("sample_(tree(...)) works", {
 test_that("sample_tree yields a singleton graph for n=1", {
   g <- sample_tree(1)
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(0))
-  expect_that(vcount(g), equals(1))
+  expect_equal(ecount(g), 0)
+  expect_equal(vcount(g), 1)
   expect_true(is_tree(g))
 })
 
 test_that("sample_tree yields a null graph for n=0", {
   g <- sample_tree(0)
   expect_false(is_directed(g))
-  expect_that(ecount(g), equals(0))
-  expect_that(vcount(g), equals(0))
+  expect_equal(ecount(g), 0)
+  expect_equal(vcount(g), 0)
   expect_false(is_tree(g)) # edge case, the null graph is not a tree even though it was generated by sample_tree()
 })
 
@@ -164,33 +164,42 @@ test_that("sample_spanning_tree works for connected graphs", {
   g <- make_full_graph(8)
 
   edges <- sample_spanning_tree(g)
-  expect_that(length(edges), equals(7))
+  expect_equal(length(edges), 7)
 
-  sg <- subgraph.edges(g, edges)
-  expect_that(vcount(sg), equals(8))
-  expect_that(ecount(sg), equals(7))
-  expect_that(sg, is_tree)
+  sg <- subgraph_from_edges(g, edges)
+  expect_equal(vcount(sg), 8)
+  expect_equal(ecount(sg), 7)
+  expect_true(is_tree(sg))
 })
 
 test_that("sample_spanning_tree works for disconnected graphs", {
   g <- make_full_graph(8) %du% make_full_graph(5)
 
   edges <- sample_spanning_tree(g, vid = 8)
-  sg <- subgraph.edges(g, edges, delete.vertices = TRUE)
-  expect_that(vcount(sg), equals(8))
-  expect_that(ecount(sg), equals(7))
-  expect_that(sg, is_tree)
+  sg <- subgraph_from_edges(g, edges, delete.vertices = TRUE)
+  expect_equal(vcount(sg), 8)
+  expect_equal(ecount(sg), 7)
+  expect_true(is_tree(sg))
 
   edges <- sample_spanning_tree(g, vid = 9)
-  sg <- subgraph.edges(g, edges, delete.vertices = TRUE)
-  expect_that(vcount(sg), equals(5))
-  expect_that(ecount(sg), equals(4))
-  expect_that(sg, is_tree)
+  sg <- subgraph_from_edges(g, edges, delete.vertices = TRUE)
+  expect_equal(vcount(sg), 5)
+  expect_equal(ecount(sg), 4)
+  expect_true(is_tree(sg))
 
   edges <- sample_spanning_tree(g)
-  sg <- subgraph.edges(g, edges, delete.vertices = FALSE)
-  expect_that(vcount(sg), equals(13))
-  expect_that(ecount(sg), equals(11))
-  expect_that(induced_subgraph(sg, 1:8), is_tree)
-  expect_that(induced_subgraph(sg, 9:13), is_tree)
+  sg <- subgraph_from_edges(g, edges, delete.vertices = FALSE)
+  expect_equal(vcount(sg), 13)
+  expect_equal(ecount(sg), 11)
+  expect_true(is_tree(induced_subgraph(sg, 1:8)))
+  expect_true(is_tree(induced_subgraph(sg, 9:13)))
+})
+
+test_that("subgraph.edges deprecation", {
+  local_igraph_options(print.id = FALSE)
+  withr::local_seed(42)
+
+  g <- make_full_graph(8) %du% make_full_graph(5)
+  edges <- sample_spanning_tree(g)
+  expect_snapshot(subgraph.edges(g, edges, delete.vertices = FALSE))
 })
